@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.4302';
+our $VERSION = '0.4303';
 
 use Moo;
 use strictures 2;
@@ -11,7 +11,6 @@ use Data::Dumper::Compact qw(ddc);
 use List::Util qw(sum0);
 use Math::Bezier ();
 use MIDI::Util qw(dura_size reverse_dump set_time_signature timidity_conf play_timidity);
-use Music::CreatingRhythms ();
 use Music::Duration ();
 use Music::RhythmSet::Util qw(upsize);
 use namespace::clean;
@@ -560,15 +559,6 @@ sub add_fill {
 }
 
 
-sub euclidean {
-    my ($self, $p, $n) = @_;
-    return '' unless $n;
-    my $mcr = Music::CreatingRhythms->new;
-    my $sequence = $mcr->euclid($p, $n);
-    return join '', @$sequence;
-}
-
-
 sub set_time_sig {
     my ($self, $signature, $set) = @_;
     $self->signature($signature) if $signature;
@@ -669,7 +659,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.4302
+version 0.4303
 
 =head1 SYNOPSIS
 
@@ -702,7 +692,7 @@ version 0.4302
   $d->note($d->sixteenth, $d->crash1);
   $d->accent_note(127, $d->sixteenth, $d->crash2);
 
-  my $patterns = [ $d->euclidean(5, 16), $d->euclidean(7, 16) ];
+  my $patterns = [ your_function(5, 16), your_function(7, 16) ];
   $d->pattern( instrument => $d->kick, patterns => $patterns );
 
   # Alternate kick and snare
@@ -1107,12 +1097,6 @@ beat-string phrase with a fill.  The fill is given as the first
 argument and should be a coderef that returns a hashref.  The default
 is a three-note, eighth-note snare fill.
 
-=head2 euclidean
-
-  $pattern = $d->euclidean($p, $n);
-
-Return the Euclidean bitstring pattern for B<p> onsets over B<n> beats.
-
 =head2 set_time_sig
 
   $d->set_time_sig;
@@ -1203,8 +1187,6 @@ L<MIDI::Util>
 
 L<Moo>
 
-L<Music::CreatingRhythms>
-
 L<Music::Duration>
 
 L<Music::RhythmSet::Util>
